@@ -100,7 +100,7 @@ class Session:
 
         if now - t > self._expiration:
             self.db.deleteSession(sessionid)
-            self.log.error("Session expired", request)
+            self.log.error("Session expired", request, login)
             raise AuthSessionExpired()
 
         self.db.updateSession(sessionid, now)
@@ -139,15 +139,21 @@ class LoginPasswordAuth(Auth, Session):
                 self.checkPassword(login, password)
             except AuthError, e:
                 e.dataset["arguments"] = request.arguments.items()
+                self.log.warning("Username and password do not match", request, login)
                 raise AuthError(message="Username and password do not match.")
+
             self.createSession(request, login)
+            self.log.warning("User login", request, login)
         else:
             login = self.checkSession(request)
 
         return self.db.getUser(login)
 
     def logout(self, request):
+        login = self.checkSession(request)
         self.deleteSession(request)
+
+        self.log.warning("User logout", request, login)
         raise AuthSessionInvalid(message="Logged out")
 
 
