@@ -506,7 +506,7 @@ class MessageSummary(Table):
                 
             if ad["data"] != None:
                 if ad["type"] == "byte-string":
-                    value = ad.get("data", escape=False)
+                    value = ad.get("data", htmlsafe=False)
                     if meaning != "payload":
                         value = utils.hexdump(value)
                 else:
@@ -644,7 +644,7 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
                 if len(results) == 0:
                     content += "<li>Invalid analyzerid:messageid pair: %s:%s</li>" % (analyzerid, ident)
                 else:
-                    alert = self.env.idmef_db.getAlert(results[0])
+                    alert = self.env.idmef_db.getAlert(results[0], htmlsafe=True)
                     link = utils.create_link("alert_summary", { "origin": "alert_listing", "ident": results[0] })
                     content += "<li><a href=\"%s\">%s</a></li>" % (link, alert["classification.text"])
 
@@ -866,7 +866,7 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         return section
         
     def render(self):
-        alert = self.env.idmef_db.getAlert(self.parameters["ident"])
+        alert = self.env.idmef_db.getAlert(self.parameters["ident"], htmlsafe=True)
         self.dataset["sections"] = [ ]
 
         self.beginSection(self.getSectionName(alert))
@@ -931,7 +931,7 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
                 data.render_table(self, "Payload", val)
 
                 payload = utils.escape_html_string(ignored_value["payload"]).replace(" ", "&nbsp;")                
-                val["payload"] = "<div style='overflow: auto;'>%s</div>" % utils.escape_html_string(ignored_value["payload"])
+                val["payload"] = "<div style='overflow: auto;'>%s</div>" % utils.escape_html_string(ignored_value["payload"]).replace("\n", "<br/>")
                 data.render_table(self, "Ascii Payload", val)
                             
             self.endTable()
@@ -942,7 +942,7 @@ class HeartbeatSummary(MessageSummary, view.View):
     view_name = "heartbeat_summary"
     
     def render(self):
-        heartbeat = self.env.idmef_db.getHeartbeat(self.parameters["ident"])
+        heartbeat = self.env.idmef_db.getHeartbeat(self.parameters["ident"], htmlsafe=True)
         self.dataset["sections"] = [ ]
 
         self.beginSection("Heartbeat")
